/*! \file ovglobals.cpp
 *  \brief Declarations of global variables
 */

#ifndef _OVGLOBALS_H_
#define _OVGLOBALS_H_

#include <GL/glew.h>
#include "ovalgebra.h"
#include "ovmesh.h"
#include "ovprojector.h"
#include "ovshader.h"
#include "ovtexture2d.h"

namespace OV
{
extern OVProjector* OVprojector; /*!<The projector used for rendering */
extern OVm4 OVrangeMatrix;       /*!< The range matrix used for scaling*/
extern OVm4 OVprojectorModelViewProjectionMatrixInverse; /*!< The inverse 
                                modelviewprojection matrix of the projector */
extern GLfloat OVmaxDisplacement; /*!< The maximum wave height */ 

extern GLint OVnoiseTexUnit;    /*!<Texture used for bumpmapping */
extern GLint OVgroundTexUnit;   /*!< Texture unit for ground texture */
extern GLint OVskyTexUnit;      /*!< Texture unit used on the sky gradient */
extern GLint OVcloudsTexUnit;   /*!< Texture unit for clouds */

extern GLint OVsunLightUnit;    /*!< Light unit for sun */

extern OVTexture2d OVnoiseTexture;  /*!< Object used for loading a noise texture */
extern OVTexture2d OVskyTexture;    /*!< Object used for loading a sky texture */

extern OVMesh OVwaterMeshLOW;   /*!< The water surface mesh, low resolution */
extern OVMesh OVwaterMeshMEDIUM;/*!< The water surface mesh, medium resolution */
extern OVMesh OVwaterMeshHIGH;  /*!< The water surface mesh, high resolution */
extern OVMesh* OVactiveMesh;    /*!< A pointer to the currently active mesh */

extern OVShader OVwaterShaderLOW;    /*!<The lowest level of detail shader */
extern OVShader OVwaterShaderMEDIUM; /*!<The medium level of detail shader */
extern OVShader OVwaterShaderHIGH;   /*!<The highest level of detail shader */
extern OVShader* OVactiveShader;     /*!<A pointer to the currently active shader */

extern float* OVcamPos;       /*!< Camera position coordinate vector, points to shell variable */
extern float* OVcamDir;       /*!< Camera direction vector, points to shell variable */
extern float* OVcamUp;        /*!< Camera up vector, points to shell variable */

extern float* OVwaterColor;   /*!< Water color vector, points to shell variable */
extern float* OVsunColor;     /*!< Sun color vector, points to shell variable */

extern float* OVtime;         /*!< Time variable, points to shell variable */
extern float* OVdayTime;      /*!< Time of the day */

extern float* OVwaterHorizon; /*!< Distance to the horizon */
extern float* OVwindVelocity; /*!< Wind velocity vector, points to shell variable */

extern float OVamplitude;      /*!< Wave amplitude */
extern float OVscaleAmplitude; /*!< Wave amplitude scale factor*/
extern float OValtitude;       /*!< Altitude, used in shader for antialiasing > */

extern GLuint* OVtexCloudID;  /*!< Cloud texture ID, points to shell variable */
extern GLuint* OVtexSkyID;    /*!< Sky texture ID, points to in shell variable */
extern GLuint* OVtexGroundID; /*!< Ground texture ID, points to shell variable */

extern int OVlodRes;          /*!<Holds current LOD */
extern int OVlodVis;          /*!<Holds current LOD shader */

extern OVv2 OVwaveVector;      /*!<Wave direction and speed */
extern OVv2 OVwaveVec1;        /*!<Wave direction and speed */
extern OVv2 OVwaveVec2;        /*!<Wave direction and speed */
extern OVv2 OVwaveVec3;        /*!<Wave direction and speed */
extern OVv2 OVwaveVec4;        /*!<Wave direction and speed */
extern OVv2 OVwaveVec5;        /*!<Wave direction and speed */
extern OVv2 OVwaveVec6;        /*!<Wave direction and speed */
extern OVv2 OVwaveVec7;        /*!<Wave direction and speed */
extern OVv2 OVwaveVec8;        /*!<Wave direction and speed */
extern OVv4 OVwaveProp1;       /*!<Wave amplitude, freq, steepness, and speed */
extern OVv4 OVwaveProp2;       /*!<Wave amplitude, freq, steepness, and speed */
extern OVv4 OVwaveProp3;       /*!<Wave amplitude, freq, steepness, and speed */
extern OVv4 OVwaveProp4;       /*!<Wave amplitude, freq, steepness, and speed */
extern OVv4 OVwaveProp5;       /*!<Wave amplitude, freq, steepness, and speed */
extern OVv4 OVwaveProp6;       /*!<Wave amplitude, freq, steepness, and speed */
extern OVv4 OVwaveProp7;       /*!<Wave amplitude, freq, steepness, and speed */
extern OVv4 OVwaveProp8;       /*!<Wave amplitude, freq, steepness, and speed */

}  // End of OV

#endif // End of _OVGLOBALS_H_
