/*! \file ovwater.h
 *  \brief Interface between OVWater and Testshell
 *
 */

#ifndef _OVWATER_H_
#define _OVWATER_H_

#include <GL/glew.h>
#include <math.h>
#include "ovglobals.h"
#include "ovalgebra.h"

namespace OV
{

void OVInitWater(float* camPos, float* camDir, float* camUp, float* time, 
                 float* dayTime, float* waterHorizon, float* windVelocity, 
                 float* waterColor, float* sunColor, int lodRes, int lodVis, 
                 GLuint* texCloudID, GLuint* texSkyID, GLuint* texGroundID,
                 float* zoomFactor, float* fovY, float* fovRatio, float* zNear,
                 float* zFar, int* windowWidth, int* windowHeight);
void OVDrawWater();
void OVDrawProjectorFrustum();
float OVGetHeight(float x,float z);
void OVSetSunLightUnit(int lightUnitID=0);
void OVSetSkyTexUnit(int texUnitID=0);
void OVSetResolutionLOD(int lodRes=3);
void OVSetVisualizationLOD(int lodVis=3);
void OVSetWaveAmpFactor(float waveAmpFactor=1.0);

void OVLoadShader(OVShader &shader, char* fileName);
void OVCalcWaveProp(int wave, OVv4& waveProp, float scaleFactor, OVv2 waveVec);
void OVRotate(float lengthScale, OVv2 k, float angle, OVv2& newK);
void OVCalcWaveProperties();

}  // End of OV

#endif
