/*! \file ovlod1.vert
 *  \brief LOD 1 vertex shader
 */

varying vec4 pInt;
varying vec4 color;
uniform mat4 rangeMatrix; //range matrix used for optimization during projection
uniform mat4 projectorModelViewProjectionMatrixInverse; //transforms from world space to image (projector) space

void main()
{
    //Colors
    vec4 cBlue = vec4(0.05,0.2,0.3, 1.0);
    vec4 cRed  = vec4(0.81,0.0,0.0, 0.0);

    //Project extremes to form line section
    vec4 pMin = gl_Vertex.xzyw;
         pMin.z = 0.0;         
         //make the coordinate range [0,1] to be compatible with the range matrix
         pMin.x= (pMin.x+1.0)/2.0;
         pMin.y= (pMin.y+1.0)/2.0;         
         pMin = projectorModelViewProjectionMatrixInverse * rangeMatrix *  pMin;
         pMin = pMin / pMin.w;
    vec4 pMax = gl_Vertex.xzyw;
         pMax.z = 1.0;         
         //make the coordinate range [0,1] to be compatible with the range matrix
         pMax.x= (pMax.x+1.0)/2.0;
         pMax.y= (pMax.y+1.0)/2.0;         
         pMax = projectorModelViewProjectionMatrixInverse * rangeMatrix *  pMax;
         pMax = pMax / pMax.w;
    /* 
     * 1: pMax.y > p.Min.y 
     *    No intersection (pMin.y > 0 always)
     * 2: pMin.y > p.Max.y > 0
     *    No intersection
     * 3: pMin.y > 0 > p.Max.y
     *    INTERSECTION
     * Solve with step functions to avoid if()'s in shader!
     */
    float isInt = abs(step(pMax.y, 0.0) - step(pMin.y, 0.0)); //intersection?

    float k = (0.0 - pMax.y) / (pMin.y - pMax.y); //relative above/below
    vec4 intersection;
    intersection.x = pMax.x + k*(pMin.x - pMax.x); //x
    intersection.y = 0.0;                         //y
    intersection.z = pMax.z + k*(pMin.z - pMax.z); //z
    intersection.w = 1.0;                          //1.0

    vec4 dump = pMax + normalize(pMax-pMin);

    pInt = mix(dump,intersection,isInt); //set according to a
    color = cBlue;  

    gl_Position = gl_ModelViewProjectionMatrix * pInt;
}
