/*! \file ovmesh.h
 *  \brief OVMesh source file.
 *
 */

#ifndef _OVMESH_H_
#define _OVMESH_H_

#include <GL/glew.h>
#include <vector>

namespace OV
{

/*! \brief OVMesh class
 *
 *  Defines a horizontal or vertical grid. Support for VBO also
 *  included.
 */
class OVMesh
{
public:
    OVMesh();
    ~OVMesh();
    void GenerateGrid(int resX, int resY, float x0, float x1, float y0,
                      float y1, bool vertical);
    void CreateVBO();
    void DeleteVBO();
    void DrawOpenGL();
    void DrawVBO();
    unsigned int GetNumTriangles();

private:
    void m_AddVertex(float x, float y, float z);
    void m_Clear();

    int	m_numVertices;    /*!< Number of vertices */
    int	m_numFaces;       /*!< Number of triangles */
    GLfloat* m_vertArray; /*!< List of vertices */
    GLuint* m_faceArray;  /*!< List of faces */
    GLuint m_vertexVBO;   /*!< Identification for VBO */
    GLuint m_indexVBO;    /*!< Identification for VBO */
};

} // End of OV

#endif // End of _OVMESH_H_
