/*! \file shader.h
 *  \brief Shader handling header file.
 *
 *  This file contains the shader object which is used to compile 
 *  and run shaders.
 */

/* History of file
 * 2007-02-28 /Johannes
 *  File created.
 * 2007-03-07 /Veronica
 *  File updated.
 * 2007-03-07 /Johannes
 *  Fixed some errors.
 * 2007-05-02 /Veronica
 *  Cleaned up the code, corrected tabs etc..
 *
 */
#ifndef _OVSHADER_H_
#define _OVSHADER_H_

#include <GL/glew.h>
#include <iostream>
#include <vector>
#include <cstring>
#include "ovunivar.h"

namespace OV
{

class OVShader
{
public:
    OVShader();
	OVShader(const char* name);
	~OVShader();
	
	void Compile(const char * shaderName);
	void UpdateUniforms();
    void UpdateUniformsLocation();
	void Activate();
	void Deactivate();
	void AddUniform(OVUniVar* uniVar);
	char* Txt2char(const char * fileName);

private:
	GLuint m_vertex;    /*!< Index of vertex program */
	GLuint m_fragment;  /*!< Index of fragment program */
	GLuint m_program;   /*!< Index of shader program */
	char* m_name;       /*!< Name of the shader */
    std::vector<OVUniVar*> m_uniforms; /*!< List of uniform variables */
};

}  // End of OV

#endif // End of _OVSHADER_H_
