/*! \file univar.cpp
 *  \brief Uniform variable source file.
 *
 *  This file contains an methods for handling uniform variables.
 */

#include "ovunivar.h"

namespace OV
{

/*! \brief Constructor for Univar
 *
 */
OVUniVar::OVUniVar() {}

/*! \brief Destructor for Univar
 *
 *  Deletes name.
 */
OVUniVar::~OVUniVar()
{
    delete[] m_name;
}

/*! \brief Updates the uniform location
 *
 *  Gets the uniform location in shader program and
 *  stores it in m_location.
 */
void OVUniVar::UpdateLocation(GLuint program)
{
    m_location = glGetUniformLocationARB(program, m_name);
}

/*! \brief Updates the value of the uniform
 *
 */
void OVUniVar::Update() {}

/*! \brief Constructor for UniVari
 *
 *  Sets name and source values.
 *
 *  \param name the variable name in shader program.
 *  \param source pointer to data.
 */
OVUniVari::OVUniVari(const char* name, int* source) 
{
    m_name = new char[std::strlen(name)+1];
    std::strcpy(m_name, name);
    m_source = source;
    m_location = -1;
}

/*! \brief Updates the value of the uniform
 *
 */
void OVUniVari::Update() 
{
    if(m_location >= 0)
        glUniform1i(m_location, *m_source);
}

/*! \brief Constructor for UniVarf
 *
 *  Sets name and source values.
 *
 *  \param name the variable name in shader program.
 *  \param source pointer to data.
 */
OVUniVarf::OVUniVarf(const char* name, float* source) 
{
    m_name = new char[std::strlen(name)+1];
    std::strcpy(m_name, name);
    m_source = source;
    m_location = -1;
}

/*! \brief Updates the value of the uniform
 *
 */
void OVUniVarf::Update() 
{
    if(m_location >= 0)
        glUniform1f(m_location, *m_source);
}

/*! \brief Constructor for UniVar2fv
 *
 *  Sets name and source values.
 *
 *  \param name the variable name in shader program.
 *  \param source pointer to data.
 */
OVUniVar2fv::OVUniVar2fv(const char* name, float* source)
{
    m_name = new char[std::strlen(name)+1];
    std::strcpy(m_name, name);
    m_source = source;
    m_location = -1;
}

/*! \brief Updates the value of the uniform
 *
 */
void OVUniVar2fv::Update() 
{
    if(m_location >= 0)
        glUniform2fv(m_location, 1, m_source);
}


/*! \brief Constructor for UniVar3fv
 *
 *  Sets name and source values.
 *
 *  \param name the variable name in shader program.
 *  \param source pointer to data.
 */
OVUniVar3fv::OVUniVar3fv(const char* name, float* source)
{
    m_name = new char[std::strlen(name)+1];
    std::strcpy(m_name, name);
    m_source = source;
    m_location = -1;
}

/*! \brief Updates the value of the uniform
 *
 */
void OVUniVar3fv::Update() 
{
    if(m_location >= 0)
        glUniform3fv(m_location, 1, m_source);
}

/*! \brief Constructor for UniVar9fm
 *
 *  Sets name and source values.
 *
 *  \param name the variable name in shader program.
 *  \param source pointer to data.
 */
OVUniVar9fm::OVUniVar9fm(const char* name, float* source) 
{
    m_name = new char[std::strlen(name)+1];
    std::strcpy(m_name, name);
    m_source = source;
    m_location = -1;
}

/*! \brief Updates the value of the uniform
 *
 */
void OVUniVar9fm::Update() 
{
    if(m_location >= 0)
        glUniformMatrix3fv(m_location, 1, false, m_source);
}

/*! \brief Constructor for UniVar4fv
 *
 *  Sets name and source values.
 *
 *  \param name the variable name in shader program.
 *  \param source pointer to data.
 */
OVUniVar4fv::OVUniVar4fv(const char* name, float* source)
{
    m_name = new char[std::strlen(name)+1];
    std::strcpy(m_name, name);
    m_source = source;
    m_location = -1;
}

/*! \brief Updates the value of the uniform
 *
 */
void OVUniVar4fv::Update() 
{
    if(m_location >= 0)
        glUniform4fv(m_location, 1, m_source);
}

/*! \brief Constructor for UniVar16fm
 *
 *  Sets name and source values.
 *
 *  \param name the variable name in shader program.
 *  \param source pointer to data.
 */
OVUniVar16fm::OVUniVar16fm(const char* name, float* source) 
{
    m_name = new char[std::strlen(name)+1];
    std::strcpy(m_name, name);
    m_source = source;
    m_location = -1;
}

/*! \brief Updates the value of the uniform
 *
 */
void OVUniVar16fm::Update()
{
    if(m_location >= 0)
        glUniformMatrix4fv(m_location, 1, false, m_source);
}

}  // End of OV
