/*! \file globals.cpp
 *  \brief Declarations of global variables
 *
 */

#include "globals.h"

//
// Misc
//

// Environment settings
GLfloat sunPosition[4];
GLfloat sunDirection[3];
GLfloat sunColor[4];
GLfloat sunAmbColor[4] = {0.4f, 0.4f, 0.3f};
GLuint sunLightSource = GL_LIGHT0;
float sunAngle = 3.1415927f/2.0f;
float windVelocity[2] = {1.0f,0.0f};
float windDir = 0.0f;
float windSpeed = 10.0f;
float waterColor[3] = {0.00f, 0.20f, 0.50f};

// Camera
GLfloat cameraPosition[4];
GLfloat cameraDirection[4];
GLfloat cameraUpVector[4];

GLfloat zoomFactor;
GLfloat fovY;
GLfloat fovRatio;
GLfloat zNear;
GLfloat zFar;

// Water settings
float waveAmpFactor = 1.0;

// Time
Timer timer;
float t;
float dt;
float daytime = 0.25;

// Quality
int lodRes=3;
int lodVis=3;

// Ground
Mesh groundMesh;
Shader groundShader;
Texture2d groundTexture;
Texture2d groundHeightTexture;
Texture2d groundNoiseTexture;

// Sky
Texture2d skyTexture;
Texture2d skyCloudTexture;
Shader skyShader;
float skyHeight;
float skyOffset;

// Boat
Texture2d boatSideTexture;
Texture2d boatDeckTexture;
Texture2d boatTopTexture;

// Render settings
GLuint polygonMode = GL_FILL;

// 
// Window management
//

int windowID = 0;
int windowWidth = 1024;
int windowHeight = 768;
Texture2d helpTexture;

//
// Keyboard input
//

// Camera movement
Camera camera;
float moveSpeed;
float turnSpeed = 90.0f;
float zoomSpeed = 1.0f;
int keyboardStrafe = 0;
int keyboardForward = 0;
int keyboardYaw = 0;
int keyboardRoll = 0;
int keyboardPitch = 0;
int keyboardZoom = 0;
int keyboardElevate = 0;

// Environment
float sunSpeed = 45.0f;
float waterHorizon = 1000.f;
int keyboardMoveSun = 0;
float windMoveSpeed = 2.0f;
int keyboardMoveWind = 0;
int keyboardTurnWind = 0; // Uses turnSpeed

// Flags
bool keyboardDrawWater = true;
bool keyboardDrawSky = true;
bool keyboardDrawTerrain = true;
bool keyboardDrawBoat = false;
bool keyboardLook = false;
bool keyboardHelp = false;
bool keyboardParameters = false;
bool keyboardFPS = true;
bool keyboardAxis = false;
bool keyboardWind = false;
bool keyboardLight = false;
