/*! \file sky.frag
 *  \brief Sky fragment shader.
 *
 */

uniform float daytime;
uniform sampler2D texSky;
uniform sampler2D texClouds;
uniform float height;
uniform float offset;

varying vec2 texSkyCoords;
varying vec3 position;
varying vec3 skyDir;

void main()
{
	texSkyCoords.t = clamp(texSkyCoords.t, 0.1, 0.9);
    vec4 skyColor = texture2D(texSky, texSkyCoords);

    float r = 2.0*(0.5-0.5*(position.y+offset)/height);
    float theta = atan(position.x, position.z);
    vec2 texCloudCoords = clamp(r*vec2(cos(theta), sin(theta))+0.5, 0.0, 0.99);

    vec4 cloudColor = texture2D(texClouds, texCloudCoords)*
                      cos(5.0*(daytime-0.25));

    float sunLight = clamp(dot(-gl_LightSource[0].spotDirection,
                               normalize(skyDir)), 0.0, 1.0);

    gl_FragColor = mix(skyColor, cloudColor, cloudColor.a) + pow(sunLight, 15)*
                   gl_LightSource[0].specular;
}
