/*! \file mesh.h
 *  \brief Mesh source file.
 *
 */

#ifndef _MESH_H_
#define _MESH_H_

#include <GL/glew.h>
#include <vector>
#include <cmath>
#include "texture2d.h"
#include "vec3.h"

/*! \brief Mesh class
 *
 *  Defines a horizontal or vertical grid. Support for VBO also
 *  included.
 */
class Mesh
{
public:
	Mesh();
    ~Mesh();
    void GenerateGrid(int resX, int resY, float x0, float x1, float y0,
					  float y1, bool vertical);
    bool LoadHeightMap(const char* filename, float x0, float x1, float y0,
                       float y1, float h0, float h1);
    void CreateVBO();
    void DeleteVBO();
    void DrawOpenGL();
    void DrawVBO();
    unsigned int GetNumTriangles();

    float hmin, hmax;

private:
    void m_AddVertex(float x, float y, float z, Vec3f& normal);
    void m_Clear();
    void m_ReadHeight(int x, int z, float dx, float dz, float h0, float h1,
                        unsigned char* data, int bytesPerPixel,
                        int width, int height, float& h, Vec3f& n);
    
    int	m_numVertices;      /*!< Number of vertices */
    int	m_numFaces;         /*!< Number of triangles */
    GLfloat* m_vertArray;   /*!< List of vertices */
    GLuint* m_faceArray;    /*!< List of faces */
    GLuint m_vertexVBO;     /*!< Identification for VBO */
    GLuint m_indexVBO;      /*!< Identification for VBO */
};

#endif // End of _MESH_H_
