/*! \file shader.h
 *  \brief Shader handling header file.
 *
 *  This file contains the shader object which is used to compile 
 *  and run shaders.
 */

#ifndef _SHADER_H_
#define _SHADER_H_

#include <GL/glew.h>
#include <iostream>
#include <vector>
#include <cstring>
#include "univar.h"

class Shader
{
public:
    Shader();
	Shader(const char* name);
	~Shader();
	
	void Compile(const char * shaderName);
	void UpdateUniforms();
    void UpdateUniformsLocation();
	void Activate();
	void Deactivate();
	void AddUniform(UniVar* uniVar);
	char* Txt2char(const char * fileName);

private:
	GLuint m_vertex;    /*!< Index of vertex program */
	GLuint m_fragment;  /*!< Index of fragment program */
	GLuint m_program;   /*!< Index of shader program */
	char* m_name;       /*!< Name of the shader */
    std::vector<UniVar*> m_uniforms; /*!< List of uniform variables */
};

#endif // End of _SHADER_H_
