/*! \file timer.h
 *  \brief Header file for timer class.
 *
 *  A high performance timer for Windows and Linux.
 */

#ifndef _TIMER_H_
#define _TIMER_H_

#ifndef WIN32
#include <sys/time.h>
#include <unistd.h>
#else
#include <windows.h>
#endif

/*! \brief Timer class.
 *
 *  A high performance timer for Windows and Linux.
 */
class Timer
{
public:
    Timer();
    void ResetTime();
    double GetDeltaTime();
    double GetDeltaTime(double max_fps);
    double GetTime();
  
private:
#ifdef WIN32
    LARGE_INTEGER m_zero; /*!< Conuter value defined as zero */
#else
    double m_zero; /*!< Time defined as zero */
#endif
    double m_time; /*!< Current time */
#ifdef WIN32
    LARGE_INTEGER m_freq; /*!< Frequency of the counter */
#endif
};

#endif // End of _TIMER_H
