/*! \file univar.cpp
 *  \brief Uniform variable source file.
 *
 *  This file contains an methods for handling uniform variables.
 */

#include "univar.h"

/*! \brief Constructor for Univar
 *
 */
UniVar::UniVar() {}

/*! \brief Destructor for Univar
 *
 *  Deletes name.
 */
UniVar::~UniVar()
{
    delete[] m_name;
}

/*! \brief Updates the uniform location
 *
 *  Gets the uniform location in shader program and
 *  stores it in m_location.
 */
void UniVar::UpdateLocation(GLuint program)
{
    m_location = glGetUniformLocationARB(program, m_name);
}

/*! \brief Updates the value of the uniform
 *
 */
void UniVar::Update() {}

/*! \brief Constructor for UniVari
 *
 *  Sets name and source values.
 *
 *  \param name the variable name in shader program.
 *  \param source pointer to data.
 */
UniVari::UniVari(const char* name, int* source) 
{
    m_name = new char[std::strlen(name)+1];
    std::strcpy(m_name, name);
    m_source = source;
    m_location = -1;
}

/*! \brief Updates the value of the uniform
 *
 */
void UniVari::Update() 
{
    if(m_location >= 0)
        glUniform1i(m_location, *m_source);
}

/*! \brief Constructor for UniVarf
 *
 *  Sets name and source values.
 *
 *  \param name the variable name in shader program.
 *  \param source pointer to data.
 */
UniVarf::UniVarf(const char* name, float* source) 
{
    m_name = new char[std::strlen(name)+1];
    std::strcpy(m_name, name);
    m_source = source;
    m_location = -1;
}

/*! \brief Updates the value of the uniform
 *
 */
void UniVarf::Update() 
{
    if(m_location >= 0)
        glUniform1f(m_location, *m_source);
}

/*! \brief Constructor for UniVar3fv
 *
 *  Sets name and source values.
 *
 *  \param name the variable name in shader program.
 *  \param source pointer to data.
 */
UniVar3fv::UniVar3fv(const char* name, float* source)
{
    m_name = new char[std::strlen(name)+1];
    std::strcpy(m_name, name);
    m_source = source;
    m_location = -1;
}

/*! \brief Updates the value of the uniform
 *
 */
void UniVar3fv::Update() 
{
    if(m_location >= 0)
        glUniform3fv(m_location, 1, m_source);
}

/*! \brief Constructor for UniVar9fm
 *
 *  Sets name and source values.
 *
 *  \param name the variable name in shader program.
 *  \param source pointer to data.
 */
UniVar9fm::UniVar9fm(const char* name, float* source) 
{
    m_name = new char[std::strlen(name)+1];
    std::strcpy(m_name, name);
    m_source = source;
    m_location = -1;
}

/*! \brief Updates the value of the uniform
 *
 */
void UniVar9fm::Update() 
{
    if(m_location >= 0)
        glUniformMatrix3fv(m_location, 1, false, m_source);
}

/*! \brief Constructor for UniVar4fv
 *
 *  Sets name and source values.
 *
 *  \param name the variable name in shader program.
 *  \param source pointer to data.
 */
UniVar4fv::UniVar4fv(const char* name, float* source)
{
    m_name = new char[std::strlen(name)+1];
    std::strcpy(m_name, name);
    m_source = source;
    m_location = -1;
}

/*! \brief Updates the value of the uniform
 *
 */
void UniVar4fv::Update() 
{
    if(m_location >= 0)
        glUniform4fv(m_location, 1, m_source);
}

/*! \brief Constructor for UniVar16fm
 *
 *  Sets name and source values.
 *
 *  \param name the variable name in shader program.
 *  \param source pointer to data.
 */
UniVar16fm::UniVar16fm(const char* name, float* source) 
{
    m_name = new char[std::strlen(name)+1];
    std::strcpy(m_name, name);
    m_source = source;
    m_location = -1;
}

/*! \brief Updates the value of the uniform
 *
 */
void UniVar16fm::Update()
{
    if(m_location >= 0)
        glUniformMatrix4fv(m_location, 1, false, m_source);
}
