/*! \file univar.h
 *  \brief Uniform variable header file.
 *
 *  This file contains an object for handling uniform variables.
 */

#ifndef _UNIVAR_H_
#define _UNIVAR_H_

#include <cstring>
#include <GL/glew.h>

/*! \brief Class that handles uniform variables.
 *
 *  This class is only used as base class for the real UniVar classes.
 *  Templates can not be used because different GL-functions are used
 *  to pass parameters to GLSL.
 */
class UniVar
{
public:
    UniVar();
    virtual ~UniVar();
    virtual void UpdateLocation(GLuint program);
    virtual void Update();

protected:
    char* m_name;       /*!< Name of the shader program */
    GLint m_location;   /*!< Location of the variable whitin the program */
};

/*! \brief UniVar integer */
class UniVari : public UniVar
{
public:
    UniVari(const char* name, int* source);
    void Update();
private:
    int* m_source; /*!< Pointer to the data source */
};

/*! \brief UniVar float */
class UniVarf : public UniVar
{
public:
    UniVarf(const char* name, float* source);
    void Update();
private:
    float* m_source; /*!< Pointer to the data source */
};

/*! \brief UniVar float vector */
class UniVar3fv : public UniVar
{
public:
    UniVar3fv(const char* name, float* source);
    void Update();
private:
    float* m_source; /*!< Pointer to the data source */
};

/*! \brief UniVar float matrix */
class UniVar9fm : public UniVar
{
public:
    UniVar9fm(const char* name, float* source);
    void Update();
private:
    float* m_source; /*!< Pointer to the data source */
};

/*! \brief UniVar float vector*/
class UniVar4fv : public UniVar
{
public:
    UniVar4fv(const char* name, float* source);
    void Update();
private:
    float* m_source; /*!< Pointer to the data source */
};

/*! \brief UniVar float matrix */
class UniVar16fm : public UniVar
{
public:
    UniVar16fm(const char* name, float* source);
    void Update();
private:
    float* m_source; /*!< Pointer to the data source */
};

#endif // End of _UNIVAR_H_
